| Title: | Peptide Annotation and Data Visualization using Gviz |
|---|---|
| Description: | Pviz adapts the Gviz package for protein sequences and data. |
| Authors: | Renan Sauteraud, Mike Jiang, Raphael Gottardo |
| Maintainer: | Renan Sauteraud <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.47.0 |
| Built: | 2026-05-30 07:03:49 UTC |
| Source: | https://github.com/bioc/Pviz |
This class contains Gviz's AnnotationTrack and adds default values to the genome and chromosome slot
ATrack(range = NULL, start = NULL, end = NULL, width = NULL, group, id, stacking = "squish", name = "ATrack", fun, selectFun, ...)ATrack(range = NULL, start = NULL, end = NULL, width = NULL, group, id, stacking = "squish", name = "ATrack", fun, selectFun, ...)
range, start, end, width, group, id, stacking, name, fun, selectFun, ...
|
Arguments to be passed to |
Renan Sauteraud
AnnotationTrack, GdObject
# Object construction aTrack <- ATrack(start = c(20, 60), end = c(40, 100), name = "random.anno", id=c("small","big")) #Stacking example a2Track <- ATrack(start = c(20, 30), end = c(40, 100), name = "stacking=dense", id = c("small", "big"), stacking = "dense", fill=c("black", "orange")) a3Track <- ATrack(start = c(20, 30), end = c(40, 100), name = "no stacking", id = c("small", "big"), fill = c("black", "orange")) #Plotting plotTracks(trackList = c(aTrack, a2Track, a3Track), showFeatureId = TRUE)# Object construction aTrack <- ATrack(start = c(20, 60), end = c(40, 100), name = "random.anno", id=c("small","big")) #Stacking example a2Track <- ATrack(start = c(20, 30), end = c(40, 100), name = "stacking=dense", id = c("small", "big"), stacking = "dense", fill=c("black", "orange")) a3Track <- ATrack(start = c(20, 30), end = c(40, 100), name = "no stacking", id = c("small", "big"), fill = c("black", "orange")) #Plotting plotTracks(trackList = c(aTrack, a2Track, a3Track), showFeatureId = TRUE)
This track can be used to display the result of pepStat analysis for a single
clade. It contains DTrack.
CladeTrack(restab, clade, name = clade, ...)CladeTrack(restab, clade, name = clade, ...)
restab |
A |
clade |
A |
name |
A |
... |
Additional argument to be passed to |
cladeA character. The clade to display.
Renan Sauteraud
DTrack
if(require(pepDat)){ data(restab) ct <- CladeTrack(restab, clade = "M", type = "l", legend = TRUE) plotTracks(ct) }if(require(pepDat)){ data(restab) ct <- CladeTrack(restab, clade = "M", type = "l", legend = TRUE) plotTracks(ct) }
This class contains Gviz's DataTrack and adds default values to the genome and chromosome slot
DTrack(range = NULL, start = NULL, end = NULL, width = NULL, data, name = "DTrack", ...)DTrack(range = NULL, start = NULL, end = NULL, width = NULL, data, name = "DTrack", ...)
range, start, end, width, data, name, ...
|
Arguments to be passed to
|
Refer to DataTrack for details regarding the constructor.
Renan Sauteraud
DataTrack, GdObject
dTrack <- DTrack(start=seq(1,1000, len=100), width=10, data=matrix(runif(400), nrow=4), name="random data")dTrack <- DTrack(start=seq(1,1000, len=100), width=10, data=matrix(runif(400), nrow=4), name="random data")
Plot an axis and the frequency of response of a single selected clade.
plot_clade(restab, clade, sequence = NULL, from = 0, to = max(restab$position), ...)plot_clade(restab, clade, sequence = NULL, from = 0, to = max(restab$position), ...)
restab |
A |
clade |
A |
sequence |
An optional |
from |
A |
to |
A |
... |
Aditional arguments to be passed to |
Renan Sauteraud
restab, plot_inter, plotTracks
if(require(pepDat)){ data(restab) plot_clade(restab, clade = c("A", "M")) }if(require(pepDat)){ data(restab) plot_clade(restab, clade = c("A", "M")) }
Plot an axis and the frequency of response of each group, averaged by peptides at each position.
plot_inter(restab, sequence = NULL, from = 0, to = max(restab$position), ...)plot_inter(restab, sequence = NULL, from = 0, to = max(restab$position), ...)
restab |
A |
sequence |
A |
from |
A |
to |
A |
... |
Aditional arguments to be passed to |
Renan Sauteraud
restab, plot_clade, plotTracks
if(require(pepDat)){ data(restab_aggregate) plot_inter(restab_aggregate) }if(require(pepDat)){ data(restab_aggregate) plot_inter(restab_aggregate) }
This track can be used to display the frequency of antibody binding for each
probe on an arrayas predicted by pepStat's function makeCalls.
ProbeTrack(sequence, intensity, probeStart, restab = NULL, group = NULL, name = "ProbeTrack", ...)ProbeTrack(sequence, intensity, probeStart, restab = NULL, group = NULL, name = "ProbeTrack", ...)
sequence |
A |
intensity |
A |
probeStart |
A |
name |
A |
restab |
A |
group |
A |
... |
Arguments to be passed to
|
The vectors for the arguments sequence, freq and
probeStart should be of the same length. If restab is provided,
the three previous arguments will be ignored and group must be
specified. group must be a valid column name in restab,
data.frame.
sequenceA character vector. The probes sequence.
probeStartA numeric vector. The start position of the probes.
intensityA numeric vector. The frequency of response of each probe.
Or the baseline corrected intensity of the signal.
Renan Sauteraud
GdObject
restab
if(require(pepDat)){ data(restab) pt <- ProbeTrack(sequence = restab$peptide, intensity = restab$group2, probeStart = restab$start) plotTracks(pt) plotTracks(pt, from = 460, to = 560, legend=TRUE) }if(require(pepDat)){ data(restab) pt <- ProbeTrack(sequence = restab$peptide, intensity = restab$group2, probeStart = restab$start) plotTracks(pt) plotTracks(pt, from = 460, to = 560, legend=TRUE) }
A track to display an axis for protein or peptide sequences
ProteinAxisTrack(range = NULL, name = "Axis", addNC = FALSE, id = NULL, ...)ProteinAxisTrack(range = NULL, name = "Axis", addNC = FALSE, id = NULL, ...)
range, name, id, ...
|
Arguments to be passed to |
addNC |
A |
Renan Sauteraud
# Object construction paxTrack <- ProteinAxisTrack() pax2 <- ProteinAxisTrack(addNC=TRUE) pax3 <- ProteinAxisTrack(littleTicks=TRUE) # Plotting plotTracks(c(paxTrack,pax2,pax3), from=1, to=100)# Object construction paxTrack <- ProteinAxisTrack() pax2 <- ProteinAxisTrack(addNC=TRUE) pax3 <- ProteinAxisTrack(littleTicks=TRUE) # Plotting plotTracks(c(paxTrack,pax2,pax3), from=1, to=100)
A track to display peptides and protein sequences.
ProteinSequenceTrack(sequence = NULL, name = "Sequence", ...)ProteinSequenceTrack(sequence = NULL, name = "Sequence", ...)
sequence |
A |
name |
A |
... |
Additional items which will all be interpreted as display parameters. |
Renan Sauteraud
if(require(pepDat)){ data(pep_hxb2) hxb2_seq <- metadata(pep_hxb2)$sequence st<-ProteinSequenceTrack(sequence=hxb2_seq, name="env") # Plotting amino acids plotTracks(st, to = 20) # When the range becomes wider, only coloured squares are displayed plotTracks(st, to = 100) # When overplotting, a single line will mark the ProteinSequenceTrack plotTracks(st) }if(require(pepDat)){ data(pep_hxb2) hxb2_seq <- metadata(pep_hxb2)$sequence st<-ProteinSequenceTrack(sequence=hxb2_seq, name="env") # Plotting amino acids plotTracks(st, to = 20) # When the range becomes wider, only coloured squares are displayed plotTracks(st, to = 100) # When overplotting, a single line will mark the ProteinSequenceTrack plotTracks(st) }